@@ -3,9 +3,17 @@ Blocks - *Sources* and *Processors* - are a backbone of you app.
 
 Finally, all functions, decorated with :code:`@source` or :code:`@processor` are reborn to these classes.
 """
-from enum import Enum
+
 from abc import ABC, abstractmethod
-from typing import Any, Union, Iterable, Optional, DefaultDict, Type, List
+from enum import Enum
+from typing import Any, Set, List, Type, Union, Iterable, Optional, DefaultDict
+
+Event = object
+EventOrEvents = Union[Event, Iterable[Event]]
+
+
+def is_named_tuple(event: EventOrEvents) -> bool:
+    return isinstance(event, tuple) and hasattr(event, '_asdict') and hasattr(event, '_fields')
 
 
 class TypeOfProcessor(Enum):
@@ -13,18 +21,6 @@ class TypeOfProcessor(Enum):
     PARALLEL = 1
 
 
-class Event(object):
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        err = '. '.join([
-            'You are going to use lightweight version of event',
-            'Define __init__-method, or use dataclasses or pydantic instead.',
-        ])
-        raise NotImplementedError(err)
-
-
-EventOrEvents = Union[Event, Iterable[Event]]
-
-
 class Source(ABC):
     """
     Interface to represent single source of events, which emits them for the further processing.
@@ -50,6 +46,10 @@ class Source(ABC):
 
       >>> blocks = (MySource(events=[MyEvent()]))
     """
+    def patch_annotations(self, out_types: Set[Type[Event]]) -> None:
+        # Just magic
+        # https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+        self.__call__.__annotations__['return'] = List[Union[tuple(out_types)]]                           # type: ignore
 
     @abstractmethod
     def __call__(self) -> EventOrEvents:
@@ -89,17 +89,15 @@ class Processor(ABC):
       >>> blocks = (Printer(state={}),)
     """
 
-    _type_of_processor: int = TypeOfProcessor.SYNC
+    _type_of_processor: TypeOfProcessor = TypeOfProcessor.SYNC
 
     @property
-    def type_of_processor(self) -> int:
+    def type_of_processor(self) -> TypeOfProcessor:
         return self._type_of_processor
 
     @type_of_processor.setter
     def type_of_processor(self, v: int) -> None:
-        if v not in (i.value for i in TypeOfProcessor):
-            raise ValueError("Incorrect type of processor")
-        self._type_of_processor = v
+        self._type_of_processor = TypeOfProcessor(v)
 
     @abstractmethod
     def __call__(self, event: Any) -> Optional[EventOrEvents]:
@@ -134,7 +132,7 @@ class AsyncSource(ABC):
         :return:        Single event or sequence of events.
         """
 
-    def close(self) -> None:
+    async def close(self) -> None:
         """Define your graceful shutdown here."""
 
 
@@ -159,7 +157,7 @@ class AsyncProcessor(ABC):
                         when result processing is unnecessary.
         """
 
-    def close(self) -> None:
+    async def close(self) -> None:
         """Define your graceful shutdown here."""
 
 
